@@ -1,6 +1,6 @@
 ##----------------------------------------------------------------------------
 ## Markdown Common Regular Expressions - ~/lib/Regexp/Common/Markdown.pm
-## Version v0.1.2
+## Version v0.1.3
 ## Copyright(c) 2020 DEGUEST Pte. Ltd.
 ## Author: Jacques Deguest <@sitael.tokyo.deguest.jp>
 ## Created 2020/08/01
@@ -19,7 +19,7 @@ BEGIN
     ## We use URI::tel instead of Regexp::Common::tel because its regular expression is antiquated
     ## URI::tel uses the latest rfc3966
     use URI::tel;
-    our $VERSION = 'v0.1.2';
+    our $VERSION = 'v0.1.3';
 
     our $SPACE_RE = qr/[[:blank:]\h]/;
     ## Including vertical space like new lines
@@ -647,7 +647,7 @@ $LIST_TYPE_ORDERED
     /x,
     
     ## This is same as the regular code block, except this allows for a code class or a code definition with class, id, etc.
-    ## https://regex101.com/r/Y9lPAz/1/tests
+    ## https://regex101.com/r/Y9lPAz/2
     ex_code_block => qr/
         (?:\n+|\A)?                                     # Necessarily at the begining of a new line or start of string
         (?<code_all>
@@ -660,45 +660,37 @@ $LIST_TYPE_ORDERED
                 )
             )
             [ \t]*
-            (?(<with_tilde>)
+            (?:
                 (?:
+                    (?<code_class>(?&_code_class))
                     (?:
-                        (?:
-                            (?<code_class>(?&_code_class))
-                            (?:
-                                [ \t]*
-                                \{[[:blank:]\h]*(?<code_attr>(?&_code_attr))[[:blank:]\h]*\}
-                            )?
-                        )
-                        |
-                        (?:
-                            \{[[:blank:]\h]*(?<code_attr>(?&_code_attr))[[:blank:]\h]*\}
-                        )
+                        [ \t]*
+                        \{[[:blank:]\h]*(?<code_attr>(?&_code_attr))[[:blank:]\h]*\}
                     )?
                 )
                 |
                 (?:
-                    (?:
-                        (?<code_class>(?&_code_class))
-                        (?:
-                            [ \t]*
-                            \{[[:blank:]\h]*(?<code_attr>(?&_code_attr))[[:blank:]\h]*\}
-                        )?
-                    )
-                    |
-                    (?:
-                        \{[[:blank:]\h]*(?<code_attr>(?&_code_attr))[[:blank:]\h]*\}
-                    )
+                    \{[[:blank:]\h]*(?<code_attr>(?&_code_attr))[[:blank:]\h]*\}
                 )
-            )
+            )?
             \n+
             (?<code_content>.*?)                        # enclosed content
             \n+
-            (?<!`)
-            \g{code_start}                              # balanced closing block marks
-            (?!`)
+            (?(<with_backtick>)
+                (?:
+                    (?<!\`)
+                    \g{code_start}                      # balanced closing block marks
+                    (?!\`)
+                )
+                |
+                (?:
+                    (?<!\~)
+                    \g{code_start}                      # balanced closing block marks
+                    (?!\~)
+                )
+            )
             [ \t]*                                      # possibly followed by some space
-            (?:\n|\Z)
+            (?:\n?|\Z)                                  # contrary to the vanilla version, we allow for no double line-break
         )
         (?<code_trailing_new_line>\n|\Z)                # and a new line or end of string
         (?(DEFINE)
@@ -1177,7 +1169,7 @@ Regexp::Common::Markdown - Markdown Common Regular Expressions
 
 =head1 VERSION
 
-    v0.1.2
+    v0.1.3
 
 =head1 DESCRIPTION
 
@@ -2172,7 +2164,7 @@ For example:
     <div>
     ~~~
 
-You can see example of this regular expression along with test units here: L<https://regex101.com/r/Y9lPAz/1/tests>
+You can see example of this regular expression along with test units here: L<https://regex101.com/r/Y9lPAz/2/tests>
 
 The capture names are:
 
@@ -2650,7 +2642,7 @@ The capture names are:
 
 =item table
 
-The entire capture of the link.
+The entire capture of the table.
 
 =item table_after
 
@@ -2660,6 +2652,8 @@ Contains the data that follows the table.
 
 Contains the table caption if set. A table caption, in markdown can be position before or after the table.
 
+If you use L<perlvar/%-> then C<$-{table_caption}->[0]> will give you the table caption if it was set at the top of the table, and C<$-{table_caption}->[1]> will give you the table caption if it was set at the bottom of the table.
+
 =item table_headers
 
 Contains the entire header rows
@@ -2674,6 +2668,10 @@ Contains the second row, if any, of the header. This is contained within the cap
 
 A second is optional and there can be only two rows in the headers as per standards.
 
+=item table_header_sep
+
+Contain the separator line between the table header and the table body.
+
 =item table_rows
 
 Contains the table body rows
